@@ -2,13 +2,13 @@
 from omdox.filters import *
 
 
-
 # set up the defaults
 # exclude these directories
 EXCLUDED_DIRNAMES = (
     '_build',
 )
-
+# the blocks to parse for code and markdown
+CONTENT_BLOCK = 'content'
 # exclude these files
 EXCLUDED_FILENAMES = (
     'layout.html',
@@ -16,6 +16,7 @@ EXCLUDED_FILENAMES = (
 # use these filters when rendering
 FILTERS = (
    'pygmentize',
+   'markdown',
 )
 
 # overwrite the defaults from local conf
